@@ -1,10 +1,27 @@
+//! A definition of a mapping structure.
+
 use crate::bind;
 
+/// A mapping that the logical button is attached to the physical index.
 #[derive(Debug)]
 pub enum MapInput {
-    Button { index: u32 },
-    Axis { index: u32 },
-    Hat { index: u32, mask: u32 },
+    /// It is attached to the button.
+    Button {
+        /// The physical index of the button.
+        index: u32,
+    },
+    /// It is attached to the axis.
+    Axis {
+        /// The physical index of the axis.
+        index: u32,
+    },
+    /// It is attached to the hat.
+    Hat {
+        /// The physical index of the hat.
+        index: u32,
+        /// The mask of the hat.
+        mask: u32,
+    },
 }
 
 impl From<bind::SDL_GameControllerButtonBind> for MapInput {
